==> language-env_0.38.tar.gz: language-env-0.38/cyr/main/dot.Xresources.pl <==
print <<"EOF";
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Emacs
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Emacs.font:                     -*-courier-medium-r-*--14-*-*-*-*-*-${FONTSET}
Emacs*menubar*Font:             -*-helvetica-bold-r-*--16-*-*-*-*-*-${FONTSET}
Emacs*menubar*background:       grey
Emacs*menubar*foreground:       grey30
Emacs.background:               lightgray
Emacs.foreground:               black
Emacs.cursorColor:              red
Emacs.bitmapIcon:               on

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! A4 paper
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Ghostview.pageMedia:            A4
XDvi.paper:                     A4

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Xman
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Xman*manualFontBold:                -*-courier-bold-r-*-*-*-120-*-*-*-*-${FONTSET}
Xman*manualFontItalic:              -*-courier-medium-o-*-*-*-120-*-*-*-*-${FONTSET}
Xman*manualFontNormal:              -*-courier-medium-r-*-*-*-120-*-*-*-*-${FONTSET}
Xman*manualFontSymbol:              -*-symbol-*-*-*-*-*-120-*-*-*-*-*-*
!Xman*directoryFontNormal:          -*-courier-medium-r-*-*-*-120-*-*-*-*-${FONTSET}
Xman*directoryFontNormal:           -*-helvetica-medium-r-*-*-*-120-*-*-*-*-${FONTSET}
!Xman*directoryFontNormal:          -*-helvetica-bold-r-*-*-*-120-*-*-*-*-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! XTerm
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
XTerm*VT100*font:            -*-fixed-medium-r-*-*-13-*-*-*-*-60-${FONTSET}
XTerm*VT100*font1:           -*-nil-*-*-*-*-*-*-*-*-*-iso8859-1
XTerm*VT100*font2:           -*-fixed-medium-r-*-*-7-*-*-*-*-50-${FONTSET}
XTerm*VT100*font3:           -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
XTerm*VT100*font4:           -*-fixed-medium-r-*-*-13-*-*-*-*-70-${FONTSET}
XTerm*VT100*font5:           -*-fixed-medium-r-*-*-15-*-*-*-*-90-${FONTSET}
XTerm*VT100*font6:           -*-fixed-medium-r-*-*-20-*-*-*-*-100-${FONTSET}
XTerm*tek4014*fontLarge:     -*-fixed-medium-r-*-*-15-*-*-*-*-90-${FONTSET}
XTerm*tek4014*font2:         -*-fixed-medium-r-*-*-13-*-*-*-*-80-${FONTSET}
XTerm*tek4014*font3:         -*-fixed-medium-r-*-*-13-*-*-*-*-60-${FONTSET}
XTerm*tek4014*fontSmall:     -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Rxvt
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Rxvt*font:                   -*-fixed-medium-r-*-*-14-*-*-*-*-70-${FONTSET}
Rxvt*font1:                  -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
Rxvt*font2:                  -*-fixed-medium-r-*-*-13-*-*-*-*-60-${FONTSET}
Rxvt*font3:                  -*-fixed-medium-r-*-*-13-*-*-*-*-80-${FONTSET}
Rxvt*font4:                  -*-fixed-medium-r-*-*-15-*-*-*-*-90-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! wterm
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
wterm*font:                  -*-fixed-medium-r-*-*-14-*-*-*-*-70-${FONTSET}
wterm*font1:                 -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
wterm*font2:                 -*-fixed-medium-r-*-*-13-*-*-*-*-60-${FONTSET}
wterm*font3:                 -*-fixed-medium-r-*-*-13-*-*-*-*-80-${FONTSET}
wterm*font4:                 -*-fixed-medium-r-*-*-15-*-*-*-*-90-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! xclipboard
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
XClipboard*Command*Font:	-*-helvetica-bold-r-normal--*-120-*-*-*-*-${FONTSET}
XClipboard*Label*Font:		-*-helvetica-bold-r-normal--*-120-*-*-*-*-${FONTSET}
XClipboard*Text*Font:		-*-courier-medium-r-normal--*-120-*-*-*-*-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! xditviev
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Xditviev*MenuButton*Font:	-*-helvetica-bold-r-normal--*-120-*-*-*-*-${FONTSET}
Xditviev*SimpleMenu*Font:	-*-helvetica-bold-r-normal--*-120-*-*-*-*-${FONTSET}
Xditviev*Text*Font:		-*-courier-medium-r-normal--*-120-*-*-*-*-${FONTSET}
EOF

==> language-env_0.57.tar.gz: language-env-0.57/cyr/main/dot.Xresources.pl <==
print <<"EOF";
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Emacs
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Emacs.font:                     -*-courier-medium-r-*--14-*-*-*-*-*-${FONTSET}
Emacs*menubar*Font:             -*-helvetica-bold-r-*--16-*-*-*-*-*-${FONTSET}
Emacs*menubar*background:       grey
Emacs*menubar*foreground:       grey30
Emacs.background:               lightgray
Emacs.foreground:               black
Emacs.cursorColor:              red
Emacs.bitmapIcon:               on

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! A4 paper
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Ghostview.pageMedia:            A4
XDvi.paper:                     A4

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Xman
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Xman*manualFontBold:                -*-courier-bold-r-*-*-*-120-*-*-*-*-${FONTSET}
Xman*manualFontItalic:              -*-courier-medium-o-*-*-*-120-*-*-*-*-${FONTSET}
Xman*manualFontNormal:              -*-courier-medium-r-*-*-*-120-*-*-*-*-${FONTSET}
Xman*manualFontSymbol:              -*-symbol-*-*-*-*-*-120-*-*-*-*-*-*
!Xman*directoryFontNormal:          -*-courier-medium-r-*-*-*-120-*-*-*-*-${FONTSET}
Xman*directoryFontNormal:           -*-helvetica-medium-r-*-*-*-120-*-*-*-*-${FONTSET}
!Xman*directoryFontNormal:          -*-helvetica-bold-r-*-*-*-120-*-*-*-*-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! XTerm
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
XTerm*VT100*font1:           -*-nil-*-*-*-*-*-*-*-*-*-iso8859-1
XTerm*VT100*font2:           -*-fixed-medium-r-*-*-7-*-*-*-*-50-${FONTSET}
XTerm*VT100*font3:           -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
XTerm*VT100*font:            -*-terminus-medium-r-*-*-14-*-*-*-*-*-${FONTSET}
XTerm*VT100*font4:           -*-terminus-medium-r-*-*-16-*-*-*-*-*-${FONTSET}
XTerm*VT100*font5:           -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}
XTerm*VT100*font6:           -*-terminus-medium-r-*-*-24-*-*-*-*-*-${FONTSET}
XTerm*tek4014*fontSmall:     -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
XTerm*tek4014*font2:         -*-terminus-medium-r-*-*-14-*-*-*-*-*-${FONTSET}
XTerm*tek4014*font3:         -*-terminus-medium-r-*-*-16-*-*-*-*-*-${FONTSET}
XTerm*tek4014*fontLarge:     -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Rxvt
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Rxvt*font1:                  -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
Rxvt*font2:                  -*-terminus-medium-r-*-*-14-*-*-*-*-*-${FONTSET}
Rxvt*font3:                  -*-terminus-medium-r-*-*-16-*-*-*-*-*-${FONTSET}
Rxvt*font:                   -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}
Rxvt*font4:                  -*-terminus-medium-r-*-*-24-*-*-*-*-*-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! wterm
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
wterm*font1:                 -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
wterm*font2:                 -*-terminus-medium-r-*-*-14-*-*-*-*-*-${FONTSET}
wterm*font3:                 -*-terminus-medium-r-*-*-16-*-*-*-*-*-${FONTSET}
wterm*font:                  -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}
wterm*font4:                 -*-terminus-medium-r-*-*-24-*-*-*-*-*-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! xclipboard
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
XClipboard*Command*Font:	-*-helvetica-bold-r-normal--*-120-*-*-*-*-${FONTSET}
XClipboard*Label*Font:		-*-helvetica-bold-r-normal--*-120-*-*-*-*-${FONTSET}
XClipboard*Text*Font:		-*-courier-medium-r-normal--*-120-*-*-*-*-${FONTSET}

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! xditviev
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Xditviev*MenuButton*Font:	-*-helvetica-bold-r-normal--*-120-*-*-*-*-${FONTSET}
Xditviev*SimpleMenu*Font:	-*-helvetica-bold-r-normal--*-120-*-*-*-*-${FONTSET}
Xditviev*Text*Font:		-*-courier-medium-r-normal--*-120-*-*-*-*-${FONTSET}
EOF
